@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 
-from django.core import mail
+import bleach
+from django.core.mail import EmailMessage, get_connection
 from django import forms
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 
 from simple_contact import settings
 
+connection = get_connection(fail_silently=True)
+
 
 class ContactForm(forms.Form):
     """
@@ -22,13 +25,23 @@ class ContactForm(forms.Form):
         Send an email message to site administrator with parameters
         filled with form field.
         """
+        self.cleaned_data['message'] = bleach.clean(
+            self.cleaned_data['message'],
+            tags=settings.ALLOWED_TAGS,
+            attributes=settings.ALLOWED_ATTRIBUTES,
+            strip_comments=True,
+        )
+
         message = render_to_string('simple_contact/contact_email.html',
             self.cleaned_data)
+        connection.open()
 
-        return mail.send_mail(
+        mail = EmailMessage(
             self.cleaned_data['subject'],
             message,
             self.cleaned_data['email'],
             [to_email, ],
-            fail_silently=True,
+            connection=connection,
         )
+        mail.content_subtype = 'html'
+        mail.send()
